==> beagle-2.1.5.tar.gz: beagle-2.1.5/beagle/Coev/src/Exception.cpp <==
/*
 *  Exception.cpp
 *  Copyright (C) 2001-2003 by Marc Parizeau
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Contact:
 *  Laboratoire de Vision et Systemes Numeriques
 *  Departement de genie electrique et de genie informatique
 *  Universite Laval, Quebec, Canada, G1K 7P4
 *  http://vision.gel.ulaval.ca
 *
 */

#include "Threading/Threading.hpp"

#ifdef WIN32
///////////// specifics for windows /////////////
#include <winsock2.h>

#else
///////////// specifics for unixes /////////////
#include <sys/errno.h>
#endif

#include <sstream>

using namespace std;
using namespace Threading;

//! Convert native OS error \c inError to Socket::Error.
Error Exception::convertNativeError(int inError)
{
   Error lCode;
   switch(inError)
   {
#ifdef WIN32
      case ERROR_NOT_OWNER: lCode = eMutexNotOwned; break;
#else
      case EPERM: lCode = eMutexNotOwned; break;
      case EDEADLK: lCode = eWouldDeadLock; break;
#endif
      default: lCode = eOtherError;
   }
   return lCode;
}

//! Return error message.
string Exception::getMessage() const throw()
{
   ostringstream lMessage;
   switch(mCode)
   {
      case eMutexNotOwned: lMessage << "MutexNotOwned"; break;
      case eWouldDeadLock: lMessage << "WouldDeadLock"; break;
      default: lMessage << "OtherError"; break;
   }
   if(mNativeCode) lMessage << " (" << mNativeCode << "): ";
   else lMessage << ": ";
   return lMessage.str()+what();
}

==> beagle-2.2.0.tar.gz: beagle-2.2.0/beagle/Coev/src/Exception.cpp <==
/*
 *  Exception.cpp
 *  Copyright (C) 2001-2003 by Marc Parizeau
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Contact:
 *  Laboratoire de Vision et Systemes Numeriques
 *  Departement de genie electrique et de genie informatique
 *  Universite Laval, Quebec, Canada, G1K 7P4
 *  http://vision.gel.ulaval.ca
 *
 */

#include "Threading/Threading.hpp"

#ifdef WIN32
///////////// specifics for windows /////////////
#include <winsock2.h>

#else
///////////// specifics for unixes /////////////
#include <sys/errno.h>
#endif

#include <sstream>

using namespace std;
using namespace Threading;

//! Convert native OS error \c inError to Socket::Error.
Threading::Error Threading::Exception::convertNativeError(int inError)
{
   Error lCode;
   switch(inError)
   {
#ifdef WIN32
      case ERROR_NOT_OWNER: lCode = eMutexNotOwned; break;
#else
      case EPERM: lCode = eMutexNotOwned; break;
      case EDEADLK: lCode = eWouldDeadLock; break;
#endif
      default: lCode = eOtherError;
   }
   return lCode;
}

//! Return error message.
string Exception::getMessage() const throw()
{
   ostringstream lMessage;
   switch(mCode)
   {
      case eMutexNotOwned: lMessage << "MutexNotOwned"; break;
      case eWouldDeadLock: lMessage << "WouldDeadLock"; break;
      default: lMessage << "OtherError"; break;
   }
   if(mNativeCode) lMessage << " (" << mNativeCode << "): ";
   else lMessage << ": ";
   return lMessage.str()+what();
}
